@@ -1,11 +1,15 @@
 import click
 import sys
+import requests
 
 from functools import update_wrapper
+
+from requests.exceptions import HTTPError
 from slai_cli.create import commands as create
 from slai_cli.model import commands as model
 from slai_cli.profile import commands as profile
 from slai_cli.decorators import requires_slai_credentials
+from slai_cli.errors import handle_error
 
 
 def with_profile(f):
@@ -29,7 +33,10 @@ def main():
     entry_point.add_command(model.model)
     entry_point.add_command(profile.profile)
 
-    entry_point()
+    try:
+        entry_point()
+    except HTTPError:
+        handle_error(error_msg="unknown_http_error")
 
 
 if __name__ == "__main__":
