@@ -119,21 +119,21 @@ class DockerClient:
         else:
             log.action(f"Created new virtual environment for model: {model_name}")
 
-    def run_trainer(self, *, model_name, model_version_id):
+    def run_trainer(self, *, model_name, model_version):
         exit_code = self._run_interactive_command(
-            cmd=f"/workspace/env/{model_name}/bin/python /workspace/models/{model_name}/{model_version_id}/trainer.py"  # noqa
+            cmd=f"/workspace/env/{model_name}/bin/python /workspace/models/{model_name}/{model_version['name']}/trainer.py"  # noqa
         )
         return exit_code
 
-    def test_model(self, *, model_name, model_version_id):
+    def test_model(self, *, model_name, model_version):
         exit_code = self._run_interactive_command(
-            cmd=f"/workspace/env/{model_name}/bin/python /workspace/bin/setup_test_environment.py {model_name} {model_version_id}"  # noqa
+            cmd=f"/workspace/env/{model_name}/bin/python /workspace/bin/setup_test_environment.py {model_name} {model_version['id']}"  # noqa
         )
         if exit_code != 0:
             return exit_code
 
         exit_code = self._run_interactive_command(
-            cmd=f"/workspace/env/{model_name}/bin/python /workspace/bin/test_model.py {model_name} {model_version_id}"  # noqa
+            cmd=f"/workspace/env/{model_name}/bin/python /workspace/bin/test_model.py {model_name} {model_version['id']} {model_version['name']}"  # noqa
         )
 
         return exit_code
@@ -155,23 +155,27 @@ class DockerClient:
         )
         return exit_code
 
-    def check_trainer_imports(self, *, model_name, model_version_id):
-        trainer_path = f"/workspace/models/{model_name}/{model_version_id}/trainer.py"
+    def check_trainer_imports(self, *, model_name, model_version):
+        trainer_path = (
+            f"/workspace/models/{model_name}/{model_version['name']}/trainer.py"
+        )
 
         exit_code = self._run_interactive_command(
             cmd=f"/workspace/env/{model_name}/bin/python /workspace/bin/check_imports.py {trainer_path}"  # noqa
         )
         return exit_code
 
-    def generate_model_handler_requirements(self, *, model_name):
+    def generate_model_handler_requirements(self, *, model_name, model_version):
         _, output = self.project_container.exec_run(
-            f"/workspace/env/{model_name}/bin/python /workspace/bin/generate_handler_requirements.py {model_name}",  # noqa
+            f"/workspace/env/{model_name}/bin/python /workspace/bin/generate_handler_requirements.py {model_name} {model_version['name']}",  # noqa
         )
         model_handler_requirements = ast.literal_eval(output.decode("utf-8"))
         return model_handler_requirements
 
-    def check_handler_imports(self, *, model_name):
-        handler_path = f"/workspace/handlers/{model_name}/handler.py"
+    def check_handler_imports(self, *, model_name, model_version):
+        handler_path = (
+            f"/workspace/handlers/{model_name}/{model_version['name']}/handler.py"
+        )
         exit_code = self._run_interactive_command(
             cmd=f"/workspace/env/{model_name}/bin/python /workspace/bin/check_imports.py {handler_path}"  # noqa
         )
